@@ -334,19 +334,19 @@ public class ReportClientBase extends AbstractJMXTools {
                     print(totals, contextDetails, macDetails, serverConfiguration, versions, parser, clc, clcYear);
                     break;
             }
-        } catch (final MalformedObjectNameException e) {
+        } catch (MalformedObjectNameException e) {
             printServerException(e, parser);
             sysexit(1);
-        } catch (final NullPointerException e) {
+        } catch (NullPointerException e) {
             printServerException(e, parser);
             sysexit(1);
-        } catch (final JSONException e) {
+        } catch (JSONException e) {
             printServerException(e, parser);
             sysexit(1);
-        } catch (final InvalidAttributeValueException e) {
+        } catch (InvalidAttributeValueException e) {
             printServerException(e, parser);
             sysexit(1);
-        } catch (final Exception e) {
+        } catch (Exception e) {
             printServerException(e, parser);
             sysexit(1);
         }
@@ -479,7 +479,6 @@ public class ReportClientBase extends AbstractJMXTools {
             put("COLLECT_EMAIL_ADDRESSES", "access-collect-email-addresses");
             put("MULTIPLE_MAIL_ACCOUNTS", "access-multiple-mail-accounts");
             put("SUBSCRIPTION", "access-subscription");
-            put("PUBLICATION", "access-publication");
             put("ACTIVE_SYNC", "access-active-sync");
             put("USM", "access-usm");
             put("OLOX20", "access-olox20");
